ListGroupLink

Struct ListGroupLink 

pub struct ListGroupLink {
    pub text: String,
    pub href: String,
    pub active: bool,
    pub disabled: bool,
    pub color: Option<Color>,
}
A list group link item.

Fields

text: Stringhref: Stringactive: booldisabled: boolcolor: Option<Color>

Implementations

pub fn new(text: impl Into<String>, href: impl Into<String>) -> Self

Create a new list group link.

Examples found in repository?
examples/bootstrap_docs.rs (line 455)
430fn list_group_section() -> Element<Section> {
431    Element::<Section>::new()
432        .attr("id", "list-group")
433        .class("mb-5")
434        .child::<H2, _>(|h| h.class("border-bottom pb-2").text("List Group"))
435        .child::<P, _>(|p| {
436            p.class("lead")
437                .text("List groups are a flexible and powerful component for displaying lists.")
438        })
439        // Basic example
440        .child::<H4, _>(|h| h.class("mt-4").text("Basic Example"))
441        .child::<Div, _>(|d| {
442            d.class("bd-example mb-3")
443                .attr("style", "max-width: 400px;")
444                .child::<Ul, _>(|_| {
445                    list_group::list_group(&["An item", "A second item", "A third item"])
446                })
447        })
448        // With links
449        .child::<H4, _>(|h| h.class("mt-4").text("Links and Buttons"))
450        .child::<Div, _>(|d| {
451            d.class("bd-example mb-3")
452                .attr("style", "max-width: 400px;")
453                .child::<Div, _>(|_| {
454                    let items = vec![
455                        list_group::ListGroupLink::new("The current link item", "#").active(),
456                        list_group::ListGroupLink::new("A second link item", "#"),
457                        list_group::ListGroupLink::new("A third link item", "#"),
458                        list_group::ListGroupLink::new("A disabled link item", "#").disabled(),
459                    ];
460                    list_group::list_group_links(&items)
461                })
462        })
463        // Flush
464        .child::<H4, _>(|h| h.class("mt-4").text("Flush"))
465        .child::<Div, _>(|d| {
466            d.class("bd-example mb-3")
467                .attr("style", "max-width: 400px;")
468                .child::<Ul, _>(|_| {
469                    list_group::list_group_flush(&["An item", "A second item", "A third item"])
470                })
471        })
472        // Numbered
473        .child::<H4, _>(|h| h.class("mt-4").text("Numbered"))
474        .child::<Div, _>(|d| {
475            d.class("bd-example mb-3")
476                .attr("style", "max-width: 400px;")
477                .child::<Ol, _>(|_| {
478                    list_group::list_group_numbered(&["A list item", "A list item", "A list item"])
479                })
480        })
481}
pub const fn active(self) -> Self

Set this link as active.

Examples found in repository?
examples/bootstrap_docs.rs (line 455)
430fn list_group_section() -> Element<Section> {
431    Element::<Section>::new()
432        .attr("id", "list-group")
433        .class("mb-5")
434        .child::<H2, _>(|h| h.class("border-bottom pb-2").text("List Group"))
435        .child::<P, _>(|p| {
436            p.class("lead")
437                .text("List groups are a flexible and powerful component for displaying lists.")
438        })
439        // Basic example
440        .child::<H4, _>(|h| h.class("mt-4").text("Basic Example"))
441        .child::<Div, _>(|d| {
442            d.class("bd-example mb-3")
443                .attr("style", "max-width: 400px;")
444                .child::<Ul, _>(|_| {
445                    list_group::list_group(&["An item", "A second item", "A third item"])
446                })
447        })
448        // With links
449        .child::<H4, _>(|h| h.class("mt-4").text("Links and Buttons"))
450        .child::<Div, _>(|d| {
451            d.class("bd-example mb-3")
452                .attr("style", "max-width: 400px;")
453                .child::<Div, _>(|_| {
454                    let items = vec![
455                        list_group::ListGroupLink::new("The current link item", "#").active(),
456                        list_group::ListGroupLink::new("A second link item", "#"),
457                        list_group::ListGroupLink::new("A third link item", "#"),
458                        list_group::ListGroupLink::new("A disabled link item", "#").disabled(),
459                    ];
460                    list_group::list_group_links(&items)
461                })
462        })
463        // Flush
464        .child::<H4, _>(|h| h.class("mt-4").text("Flush"))
465        .child::<Div, _>(|d| {
466            d.class("bd-example mb-3")
467                .attr("style", "max-width: 400px;")
468                .child::<Ul, _>(|_| {
469                    list_group::list_group_flush(&["An item", "A second item", "A third item"])
470                })
471        })
472        // Numbered
473        .child::<H4, _>(|h| h.class("mt-4").text("Numbered"))
474        .child::<Div, _>(|d| {
475            d.class("bd-example mb-3")
476                .attr("style", "max-width: 400px;")
477                .child::<Ol, _>(|_| {
478                    list_group::list_group_numbered(&["A list item", "A list item", "A list item"])
479                })
480        })
481}
pub const fn disabled(self) -> Self

Set this link as disabled.

Examples found in repository?
examples/bootstrap_docs.rs (line 458)
430fn list_group_section() -> Element<Section> {
431    Element::<Section>::new()
432        .attr("id", "list-group")
433        .class("mb-5")
434        .child::<H2, _>(|h| h.class("border-bottom pb-2").text("List Group"))
435        .child::<P, _>(|p| {
436            p.class("lead")
437                .text("List groups are a flexible and powerful component for displaying lists.")
438        })
439        // Basic example
440        .child::<H4, _>(|h| h.class("mt-4").text("Basic Example"))
441        .child::<Div, _>(|d| {
442            d.class("bd-example mb-3")
443                .attr("style", "max-width: 400px;")
444                .child::<Ul, _>(|_| {
445                    list_group::list_group(&["An item", "A second item", "A third item"])
446                })
447        })
448        // With links
449        .child::<H4, _>(|h| h.class("mt-4").text("Links and Buttons"))
450        .child::<Div, _>(|d| {
451            d.class("bd-example mb-3")
452                .attr("style", "max-width: 400px;")
453                .child::<Div, _>(|_| {
454                    let items = vec![
455                        list_group::ListGroupLink::new("The current link item", "#").active(),
456                        list_group::ListGroupLink::new("A second link item", "#"),
457                        list_group::ListGroupLink::new("A third link item", "#"),
458                        list_group::ListGroupLink::new("A disabled link item", "#").disabled(),
459                    ];
460                    list_group::list_group_links(&items)
461                })
462        })
463        // Flush
464        .child::<H4, _>(|h| h.class("mt-4").text("Flush"))
465        .child::<Div, _>(|d| {
466            d.class("bd-example mb-3")
467                .attr("style", "max-width: 400px;")
468                .child::<Ul, _>(|_| {
469                    list_group::list_group_flush(&["An item", "A second item", "A third item"])
470                })
471        })
472        // Numbered
473        .child::<H4, _>(|h| h.class("mt-4").text("Numbered"))
474        .child::<Div, _>(|d| {
475            d.class("bd-example mb-3")
476                .attr("style", "max-width: 400px;")
477                .child::<Ol, _>(|_| {
478                    list_group::list_group_numbered(&["A list item", "A list item", "A list item"])
479                })
480        })
481}
pub const fn color(self, color: Color) -> Self

Set a contextual color.