pub enum DropdownItem {
Link {
text: String,
href: String,
},
Active {
text: String,
href: String,
},
Disabled {
text: String,
href: String,
},
Divider,
Header(String),
Text(String),
}Expand description
A dropdown menu item.
Variants
Link
A clickable link item.
Active
An active (highlighted) link item.
Disabled
A disabled link item.
Divider
A divider line.
Header(String)
A non-interactive header.
Text(String)
Plain text (non-interactive).
Implementations
Sourceimpl DropdownItem
impl DropdownItem
Sourcepub fn link(text: impl Into<String>, href: impl Into<String>) -> Self
pub fn link(text: impl Into<String>, href: impl Into<String>) -> Self
Create a link item.
Examples found in repository?
examples/bootstrap_docs.rs (line 748)
735fn dropdown_section() -> Element<Section> {
736 Element::<Section>::new()
737 .attr("id", "dropdowns")
738 .class("mb-5")
739 .child::<H2, _>(|h| h.class("border-bottom pb-2").text("Dropdowns"))
740 .child::<P, _>(|p| {
741 p.class("lead")
742 .text("Toggle contextual overlays for displaying lists of links and more.")
743 })
744 .child::<H4, _>(|h| h.class("mt-4").text("Single Button"))
745 .child::<Div, _>(|d| {
746 d.class("bd-example mb-3").child::<Div, _>(|_| {
747 let items = vec![
748 dropdown::DropdownItem::link("Action", "#"),
749 dropdown::DropdownItem::link("Another action", "#"),
750 dropdown::DropdownItem::divider(),
751 dropdown::DropdownItem::link("Separated link", "#"),
752 ];
753 dropdown::dropdown(Color::Primary, "Dropdown button", &items)
754 })
755 })
756 .child::<H4, _>(|h| h.class("mt-4").text("Split Button"))
757 .child::<Div, _>(|d| {
758 d.class("bd-example mb-3").child::<Div, _>(|_| {
759 let items = vec![
760 dropdown::DropdownItem::link("Action", "#"),
761 dropdown::DropdownItem::link("Another action", "#"),
762 dropdown::DropdownItem::divider(),
763 dropdown::DropdownItem::link("Separated link", "#"),
764 ];
765 dropdown::dropdown_split(Color::Success, "Action", "#", &items)
766 })
767 })
768 .child::<H4, _>(|h| h.class("mt-4").text("Directions"))
769 .child::<Div, _>(|d| {
770 let items = vec![dropdown::DropdownItem::link("Action", "#")];
771 d.class("bd-example mb-3")
772 .child::<Div, _>(|d| {
773 d.class("d-inline-block me-2")
774 .child::<Div, _>(|_| dropdown::dropup(Color::Secondary, "Dropup", &items))
775 })
776 .child::<Div, _>(|d| {
777 d.class("d-inline-block me-2")
778 .child::<Div, _>(|_| dropdown::dropend(Color::Secondary, "Dropend", &items))
779 })
780 .child::<Div, _>(|d| {
781 d.class("d-inline-block").child::<Div, _>(|_| {
782 dropdown::dropstart(Color::Secondary, "Dropstart", &items)
783 })
784 })
785 })
786}Sourcepub fn active(text: impl Into<String>, href: impl Into<String>) -> Self
pub fn active(text: impl Into<String>, href: impl Into<String>) -> Self
Create an active link item.
Sourcepub fn disabled(text: impl Into<String>, href: impl Into<String>) -> Self
pub fn disabled(text: impl Into<String>, href: impl Into<String>) -> Self
Create a disabled link item.
Sourcepub const fn divider() -> Self
pub const fn divider() -> Self
Create a divider.
Examples found in repository?
examples/bootstrap_docs.rs (line 750)
735fn dropdown_section() -> Element<Section> {
736 Element::<Section>::new()
737 .attr("id", "dropdowns")
738 .class("mb-5")
739 .child::<H2, _>(|h| h.class("border-bottom pb-2").text("Dropdowns"))
740 .child::<P, _>(|p| {
741 p.class("lead")
742 .text("Toggle contextual overlays for displaying lists of links and more.")
743 })
744 .child::<H4, _>(|h| h.class("mt-4").text("Single Button"))
745 .child::<Div, _>(|d| {
746 d.class("bd-example mb-3").child::<Div, _>(|_| {
747 let items = vec![
748 dropdown::DropdownItem::link("Action", "#"),
749 dropdown::DropdownItem::link("Another action", "#"),
750 dropdown::DropdownItem::divider(),
751 dropdown::DropdownItem::link("Separated link", "#"),
752 ];
753 dropdown::dropdown(Color::Primary, "Dropdown button", &items)
754 })
755 })
756 .child::<H4, _>(|h| h.class("mt-4").text("Split Button"))
757 .child::<Div, _>(|d| {
758 d.class("bd-example mb-3").child::<Div, _>(|_| {
759 let items = vec![
760 dropdown::DropdownItem::link("Action", "#"),
761 dropdown::DropdownItem::link("Another action", "#"),
762 dropdown::DropdownItem::divider(),
763 dropdown::DropdownItem::link("Separated link", "#"),
764 ];
765 dropdown::dropdown_split(Color::Success, "Action", "#", &items)
766 })
767 })
768 .child::<H4, _>(|h| h.class("mt-4").text("Directions"))
769 .child::<Div, _>(|d| {
770 let items = vec![dropdown::DropdownItem::link("Action", "#")];
771 d.class("bd-example mb-3")
772 .child::<Div, _>(|d| {
773 d.class("d-inline-block me-2")
774 .child::<Div, _>(|_| dropdown::dropup(Color::Secondary, "Dropup", &items))
775 })
776 .child::<Div, _>(|d| {
777 d.class("d-inline-block me-2")
778 .child::<Div, _>(|_| dropdown::dropend(Color::Secondary, "Dropend", &items))
779 })
780 .child::<Div, _>(|d| {
781 d.class("d-inline-block").child::<Div, _>(|_| {
782 dropdown::dropstart(Color::Secondary, "Dropstart", &items)
783 })
784 })
785 })
786}Auto Trait Implementations
impl Freeze for DropdownItem
impl RefUnwindSafe for DropdownItem
impl Send for DropdownItem
impl Sync for DropdownItem
impl Unpin for DropdownItem
impl UnwindSafe for DropdownItem